==> vtigercrm-5.3.0p0.tgz: vtigercrm/modules/Campaigns/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
// Added in release 5.0
'LBL_CAMPAIGN_INFORMATION'=>'Campaign Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',
'LBL_EXPECTATIONS_AND_ACTUALS'=>'Expectations & Actuals',

'Campaign Name'=>'Campaign Name',
'Campaign Type'=>'Campaign Type',
'Campaign Status'=>'Campaign Status',
'Campaign ID'=>'Campaign ID',
'Expected Close Date'=>'Expected Close Date',
'Expected Revenue'=>'Expected Revenue',
'Budget Cost'=>'Budget Cost',
'Actual Cost'=>'Actual Cost',
'Expected Response'=>'Expected Response',
'Assigned To'=>'Assigned To',
'Num Sent'=>'Num Sent',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Description'=>'Description',
'Product'=>'Product',
'Target Audience'=>'Target Audience',
'TargetSize'=>'Target Size',
'Sponsor'=>'Sponsor',

'Expected Sales Count'=>'Expected Sales Count',
'Expected Response Count'=>'Expected Response Count',
'Expected ROI'=>'Expected ROI',

'Actual Sales Count'=>'Actual Sales Count',
'Actual Response Count'=>'Actual Response Count',
'Actual ROI'=>'Actual ROI',
'Select One'=>'Select One',
'LBL_LOAD_LIST'=>'Load List',

//Added for existing Picklist Entries

'Conference'=>'Conference',
'Webinar'=>'Webinar',
'Trade Show'=>'Trade Show',				    
'Public Relations'=>'Public Relations',
'Partners'=>'Partners',
'Referral Program'=>'Referral Program',
'Advertisement'=>'Advertisement',
'Banner Ads'=>'Banner Ads',
'Direct Mail'=>'Direct Mail',
'Email'=>'Email',
'Telemarketing'=>'Telemarketing',
'Others'=>'Others',

'Planning'=>'Planning',						      	    
'Active'=>'Active',	
'Inactive'=>'Inactive',
'Complete'=>'Complete',
'Cancelled'=>'Cancelled',							      

'Excellent'=>'Excellent',
'Good'=>'Good',
'Average'=>'Average',
'Poor'=>'Poor',
			      
//Module Sequence Numbering
'Campaign No'=>'Campaign No',
// status fields 
'--None--'=>'--None--',
'Contacted - Successful' => 'Contacted - Successful',
'Contacted - Unsuccessful' => 'Contacted - Unsuccessful',
'Contacted - Never Contact Again' => 'Contacted - Never Contact Again'
// END

);

?>

==> vtigercrm-5.4.0.tgz: vtigercrm/modules/Campaigns/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for Campaign Module
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
// Added in release 5.0
'LBL_CAMPAIGN_INFORMATION'=>'Campaign Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',
'LBL_EXPECTATIONS_AND_ACTUALS'=>'Expectations & Actuals',

'Campaign Name'=>'Campaign Name',
'Campaign Type'=>'Campaign Type',
'Campaign Status'=>'Campaign Status',
'Campaign ID'=>'Campaign ID',
'Expected Close Date'=>'Expected Close Date',
'Expected Revenue'=>'Expected Revenue',
'Budget Cost'=>'Budget Cost',
'Actual Cost'=>'Actual Cost',
'Expected Response'=>'Expected Response',
'Assigned To'=>'Assigned To',
'Num Sent'=>'Num Sent',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Description'=>'Description',
'Product'=>'Product',
'Target Audience'=>'Target Audience',
'TargetSize'=>'Target Size',
'Sponsor'=>'Sponsor',

'Expected Sales Count'=>'Expected Sales Count',
'Expected Response Count'=>'Expected Response Count',
'Expected ROI'=>'Expected ROI',

'Actual Sales Count'=>'Actual Sales Count',
'Actual Response Count'=>'Actual Response Count',
'Actual ROI'=>'Actual ROI',
'Select One'=>'Select One',
'LBL_LOAD_LIST'=>'Load List',

//Added for existing Picklist Entries

'Conference'=>'Conference',
'Webinar'=>'Webinar',
'Trade Show'=>'Trade Show',				    
'Public Relations'=>'Public Relations',
'Partners'=>'Partners',
'Referral Program'=>'Referral Program',
'Advertisement'=>'Advertisement',
'Banner Ads'=>'Banner Ads',
'Direct Mail'=>'Direct Mail',
'Email'=>'Email',
'Telemarketing'=>'Telemarketing',
'Others'=>'Others',

'Planning'=>'Planning',						      	    
'Active'=>'Active',	
'Inactive'=>'Inactive',
'Complete'=>'Complete',
'Cancelled'=>'Cancelled',							      

'Excellent'=>'Excellent',
'Good'=>'Good',
'Average'=>'Average',
'Poor'=>'Poor',
			      
//Module Sequence Numbering
'Campaign No'=>'Campaign No',
// status fields 
'--None--'=>'--None--',
'Contacted - Successful' => 'Contacted - Successful',
'Contacted - Unsuccessful' => 'Contacted - Unsuccessful',
'Contacted - Never Contact Again' => 'Contacted - Never Contact Again',
// END
'Campaigns ID' => 'Campaigns ID',
);

?>
